@@ -22,7 +22,13 @@ ContentNode::~ContentNode()
 Glib::ustring ContentNode::get_content() const
 {
   if(cobj()->type == XML_ELEMENT_NODE)
+  {
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("this node type doesn't have content");
+    #else
+    return Glib::ustring();
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
+  }
 
   return cobj()->content ? (char*)cobj()->content : "";
 }
@@ -30,9 +36,16 @@ Glib::ustring ContentNode::get_content() const
 void ContentNode::set_content(const Glib::ustring& content)
 {
    if(cobj()->type == XML_ELEMENT_NODE)
-      throw internal_error("can't set content for this node type");
+   {
+     #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
+     throw internal_error("can't set content for this node type");
+     #else
+     return;
+     #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
+   }
+      
 
-   xmlNodeAddContent(cobj(), (xmlChar*)content.c_str());
+   xmlNodeSetContent(cobj(), (xmlChar*)content.c_str());
 }
 
 bool ContentNode::is_white_space() const
